/*
 * c2djs-helper
 * https://github.com/Hou/GruntProject
 *
 * Copyright (c) 2017 life4fun.net
 * Licensed under the MIT license.
 */

'use strict';

module.exports = function (grunt) {

    // Project configuration.
    grunt.initConfig({
        jshint: {
            all: [
                'Gruntfile.js',
                'tasks/*.js',
                '<%= nodeunit.tests %>'
            ],
            options: {
                jshintrc: '.jshintrc'
            }
        },

        // Before generating any new files, remove any previously-created files.
        clean: {
            tests: ['tmp']
        },

        // Configuration to be run (and then tested).
        c2djs_helper: {
            default_options: {
                options: {
                },
                files: {
                    'tmp/default/resource.js': ['test/fixtures/res']
                }
            },

            custom_options: {
                options: {
                    sort: true,
                    extension: '{*.png,*.jpg,*.JPEG}',
                    lazyLoadRegex: /LazyLoadImg_[0-9]{0,}_jpg/,
                    withTTF: true
                },
                files: {
                    'tmp/custom/resource.js': ['test/fixtures/res']
                }
            }
        },

        // Unit tests.
        nodeunit: {
            tests: ['test/*_test.js']
        }

    });

    // Actually load this plugin's task(s).
    grunt.loadTasks('tasks');

    // These plugins provide necessary tasks.
    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-nodeunit');

    // Whenever the "test" task is run, first clean the "tmp" dir, then run this
    // plugin's task(s), then test the result.
    grunt.registerTask('test', ['clean', 'c2djs_helper', 'nodeunit']);

    // By default, lint and run all tests.
    grunt.registerTask('default', ['jshint', 'test']);

};
